@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: polyparse
-version: 1.7
-id: polyparse-1.7-58cfb7e141a2e7fa074f9bcff3b12686
+version: 1.9
+id: polyparse-1.9-b5f5bd214b1b2a7afc4372c48e61bd4a
 
 license: LGPL
 copyright:
@@ -9,6 +9,7 @@ maintainer: author
 stability:
 homepage: http://code.haskell.org/~malcolm/polyparse/
 package-url:
+synopsis: A variety of alternative parser combinator libraries.
 description: A variety of alternative parser combinator libraries, including
              the original HuttonMeijer set.  The Poly sets have features like
              good error reporting, arbitrary token type, running state, lazy
@@ -20,7 +21,8 @@ author: Malcolm Wallace <Malcolm.Wallace@me.com>
 pkgpath: textproc/hs-polyparse
 exposed: True
 exposed-modules: Text.ParserCombinators.Poly.ByteString
-                 Text.Parse.ByteString Text.ParserCombinators.Poly.Text
+                 Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
+                 Text.ParserCombinators.Poly.Text
                  Text.ParserCombinators.Poly.StateText
                  Text.ParserCombinators.HuttonMeijer
                  Text.ParserCombinators.HuttonMeijerWallace
@@ -33,21 +35,22 @@ exposed-modules: Text.ParserCombinators.Poly.ByteString
                  Text.ParserCombinators.Poly.StateLazy
                  Text.ParserCombinators.Poly.Lex Text.Parse
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/polyparse-1.7
-library-dirs: /usr/local/lib/ghc/polyparse-1.7
-hs-libraries: HSpolyparse-1.7
+trusted: False
+import-dirs: /usr/local/lib/ghc/polyparse-1.9
+library-dirs: /usr/local/lib/ghc/polyparse-1.9
+hs-libraries: HSpolyparse-1.9
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
-         text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
+depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
+         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-polyparse-1.7/html/polyparse.haddock
-haddock-html: /usr/local/share/doc/hs-polyparse-1.7/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-polyparse-1.9/html/polyparse.haddock
+haddock-html: /usr/local/share/doc/hs-polyparse-1.9/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
